@@ -1,7 +1,9 @@
 """Dojo Specific Widgets"""
 
 from tw.dojo import DojoQueryReadStore, DojoBase, grid_css, tundragrid_css
+from tw.dojo.selectshuttle import DojoSelectShuttleField
 from tw.api import JSSource
+from sprox.widgets import PropertyMixin
 
 class SproxDojoGrid(DojoBase):
     css = [grid_css, tundragrid_css]
@@ -12,7 +14,7 @@ class SproxDojoGrid(DojoBase):
               'columnResizing', 'columnReordering'
               ]
     delayScroll = "true"
-    cssclass=""
+    cssclass="sprox-dojo-grid"
     rowsPerPage = 20
     columns = []
     columnReordering = "false"
@@ -62,4 +64,10 @@ class SproxEditableDojoGrid(DojoBase):
     </thead>
     <div dojoType="dojox.data.QueryReadStore" jsId="${jsId}_store"  id="${jsId}_store" url="${action}"/>
     </table>
-    """
\ No newline at end of file
+    """
+    
+class SproxDojoSelectShuttleField(DojoSelectShuttleField, PropertyMixin):
+    def update_params(self, d):
+        self._my_update_params(d)
+        super(SproxDojoSelectShuttleField, self).update_params(d)
+
